==> ejc-technologymanage-api-3.0.0-20230619.104443-30-sources.jar: com/ejianc/business/constructor/vo/ProgramReportVO.java <==
package com.ejianc.business.constructor.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 施组方案报表
 * 
 * @author generator
 * 
 */
public class ProgramReportVO{

    private Long projectId;
    private String projectName;
    private Long fazdId;//方案字典id
    private String fazdName;//方案字典名称
    private Integer planNum;//计划数量
    private Integer approveNum;//审批通过数量
    private Integer approvingNum;//审批中数量
    private Integer freeNum;//自由态
    private String tags;//分类标签

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getFazdId() {
        return fazdId;
    }

    public void setFazdId(Long fazdId) {
        this.fazdId = fazdId;
    }

    public String getFazdName() {
        return fazdName;
    }

    public void setFazdName(String fazdName) {
        this.fazdName = fazdName;
    }

    public Integer getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Integer planNum) {
        this.planNum = planNum;
    }

    public Integer getApproveNum() {
        return approveNum;
    }

    public void setApproveNum(Integer approveNum) {
        this.approveNum = approveNum;
    }

    public Integer getApprovingNum() {
        return approvingNum;
    }

    public void setApprovingNum(Integer approvingNum) {
        this.approvingNum = approvingNum;
    }

    public Integer getFreeNum() {
        return freeNum;
    }

    public void setFreeNum(Integer freeNum) {
        this.freeNum = freeNum;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }
}

==> ejc-technologymanage-api-3.0.0-20230620.015019-31-sources.jar: com/ejianc/business/constructor/vo/ProgramReportVO.java <==
package com.ejianc.business.constructor.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 施组方案报表
 * 
 * @author generator
 * 
 */
public class ProgramReportVO{
    private Long planId;//计划id
    private Long projectId;
    private String projectName;
    private Long fazdId;//方案字典id
    private String fazdName;//方案字典名称
    private Integer planNum;//计划数量
    private Integer approveNum;//审批通过数量
    private Integer approvingNum;//审批中数量
    private Integer freeNum;//自由态
    private String tags;//分类标签
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date planDate;//计划编制时间
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date approveTime;//审批完成时间


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getFazdId() {
        return fazdId;
    }

    public void setFazdId(Long fazdId) {
        this.fazdId = fazdId;
    }

    public String getFazdName() {
        return fazdName;
    }

    public void setFazdName(String fazdName) {
        this.fazdName = fazdName;
    }

    public Integer getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Integer planNum) {
        this.planNum = planNum;
    }

    public Integer getApproveNum() {
        return approveNum;
    }

    public void setApproveNum(Integer approveNum) {
        this.approveNum = approveNum;
    }

    public Integer getApprovingNum() {
        return approvingNum;
    }

    public void setApprovingNum(Integer approvingNum) {
        this.approvingNum = approvingNum;
    }

    public Integer getFreeNum() {
        return freeNum;
    }

    public void setFreeNum(Integer freeNum) {
        this.freeNum = freeNum;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }

    public Date getApproveTime() {
        return approveTime;
    }

    public void setApproveTime(Date approveTime) {
        this.approveTime = approveTime;
    }
}
